restart

-- define field extension Q[y*];
-- in the file y* is denoted y

F = QQ[y]/(y^27 - 2*y^26 + 17*y^25 - 29*y^24 + 81*y^23 + 52*y^22 - 726*y^21 + 3451*y^20 - 10901*y^19 + 25738*y^18 - 50663*y^17 + 72133*y^16 - 72973*y^15 + 10444*y^14 + 138860*y^13 - 308611*y^12 + 427344*y^11 - 267416*y^10 - 196096*y^9 + 762736*y^8 - 1236736*y^7 + 1092352*y^6 - 537600*y^5 - 42240*y^4 + 684032*y^3 - 1136640*y^2 + 1146880*y - 520192)

-- load expressions of the y_i's in terms of y*
-- in the file, they are polynomials yy_i of degree at most 26 in y

load "yy_exps.m2"


-- define a polynomial ring in 44 variables z

R = F[z_1..z_44]

-- load the equations of type 1: these are 14 equations.

load "eqnsType2.m2"


-- load the list of the monomials occurring in the equations
-- this is a list of 30 objects, one for each equation:
-- each object is a list of triples: (monomial, expression, coefficient)
-- monomial is a monomial occurring in the equation
-- expression is the expression of the monomial in terms of u and y;
--            the first monomial of each equation is the chosen u.
-- coefficient is the coefficient of the monomial in the equation
RRR = R[u]
load "monomialsType2.m2"

-- this evaluates the cube of each z_i by replacing it by yy_i

cubingZ = toList apply(1..44 ,i-> z_i => yy_i);


-- we prove that for every equation there is a monomial u such that Q[u^3] = Q[y]
-- we evaluate the expression p(y) of u^3 and we show that Q[p(y)] = Q[y]
-- this is guaranteed by the matrix of change of basis in full rank.

princMon3 = apply(Mon, M -> sub((M_0)_0, cubingZ));
apply(40, j-> (
	print(j);
	u3 = princMon3_j;
	u3powers = matrix{apply(27,i-> u3^i)};
	u3spowers = matrix{apply(27,i-> u^(3*i))};
	ypowers = matrix{apply(27, i-> y^i)};
	mat = sub(contract(transpose ypowers, u3powers),y=>0);
	rank mat))


-- this cycle checks that the cubes of the expressions of the monomials in the z's 
-- equal the corresponding monomial in the y's;
ZZZ =  for M in Mon do (
    u3 = sub( (M_0)_0,cubingZ);
    K = F[u]/(u^3-u3);
    for m in M do (
	print (sub(sub(sub(m_0,R),cubingZ),K) - sub((m_1)^3,K) )))

-- this cycle checks that the coefficients of the equations correctly output the corresponding equation

apply(40, i-> (
	M = Mon_i;
	sum(M, m -> m_2*m_0) - e_(i+1)))

-- this cycle checks that the monomials, expressed as polynomials in y, satisfy the equations.
apply(40, i-> (
	M = Mon_i;
	sum(M, m -> m_2*m_1) ))


